@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2010 by Stephen Allewell
- * sallewell@users.sourceforge.net
+ * Copyright (C) 2010-2015 by Stephen Allewell
+ * steve.allewell@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,6 +61,7 @@
 #include "PrintSetupDlg.h"
 #include "QVariantPtr.h"
 #include "Scale.h"
+#include "ScaledPixmapLabel.h"
 #include "SchemeManager.h"
 #include "SymbolLibrary.h"
 #include "SymbolManager.h"
@@ -456,21 +457,30 @@ void MainWindow::filePrint()
 void MainWindow::printPages()
 {
     QList<Page *> pages = m_document->printerConfiguration().pages();
+
+    int fromPage = 1;
+    int toPage = pages.count();
+
+    if (m_printer->printRange() == QPrinter::PageRange) {
+        fromPage = m_printer->fromPage();
+        toPage = m_printer->toPage();
+    }
+
+    while (toPage < pages.count()) pages.removeLast();
+    while (--fromPage) pages.removeFirst();
+
     int totalPages = pages.count();
 
+    const Page *page = (m_printer->pageOrder() == QPrinter::FirstPageFirst)?pages.takeFirst():pages.takeLast();
+
+    m_printer->setPaperSize(page->paperSize());             // DEPRECATED
+    m_printer->setOrientation(page->orientation());         // DEPRECATED
+
     QPainter painter;
-
-    const Page *page = pages.at(0);
-
-    m_printer->setPaperSize(page->paperSize());
-    m_printer->setOrientation(page->orientation());
+    painter.begin(m_printer);
+    painter.setRenderHint(QPainter::Antialiasing, true);
 
     for (int p = 0 ; p < totalPages ;) {
-        if (!painter.isActive()) {
-            painter.begin(m_printer);
-            painter.setRenderHint(QPainter::Antialiasing, true);
-        }
-
         int paperWidth = PaperSizes::width(page->paperSize(), page->orientation());
         int paperHeight = PaperSizes::height(page->paperSize(), page->orientation());
 
@@ -479,14 +489,10 @@ void MainWindow::printPages()
         page->render(m_document, &painter);
 
         if (++p < totalPages) {
-            page = pages.at(p);
+            page = (m_printer->pageOrder() == QPrinter::FirstPageFirst)?pages.takeFirst():pages.takeLast();
 
-            if (painter.device()->paintEngine()->type() == QPaintEngine::PostScript) {
-                painter.end();
-            }
-
-            m_printer->setPaperSize(page->paperSize());
-            m_printer->setOrientation(page->orientation());
+            m_printer->setPaperSize(page->paperSize());     // DEPRECATED
+            m_printer->setOrientation(page->orientation()); // DEPRECATED
 
             m_printer->newPage();
         }
@@ -580,7 +586,11 @@ void MainWindow::convertImage(const QString &source)
                 if (!(packet.opacity)) {
                     if (!(ignoreColor && Magick::Color(packet) == ignoreColorValue)) {
                         int flossIndex;
+#if MAGICKCORE_QUANTUM_DEPTH == 8
+                        QColor color(packet.red, packet.green, packet.blue);
+#else
                         QColor color(packet.red / 256, packet.green / 256, packet.blue / 256);
+#endif
 
                         for (flossIndex = 0 ; flossIndex < documentFlosses.count() ; flossIndex++) {
                             if (documentFlosses[flossIndex] == color) {
@@ -644,7 +654,7 @@ void MainWindow::convertPreview(const QString &source)
 {
     QPixmap pixmap;
     pixmap.load(source);
-    m_imageLabel->setPixmap(pixmap.scaled(300, 300, Qt::KeepAspectRatio));
+    m_imageLabel->setPixmap(pixmap);
 }
 
 
@@ -997,7 +1007,7 @@ void MainWindow::loadSettings()
 
     actions->action("makesCopies")->setChecked(Configuration::tool_MakesCopies());
 
-    actions->action("colorHilight")->setChecked(Configuration::renderer_ColorHilight());
+    actions->action("colorHighlight")->setChecked(Configuration::renderer_ColorHilight());
 
     actions->action("renderStitches")->setChecked(Configuration::renderer_RenderStitches());
     actions->action("renderBackstitches")->setChecked(Configuration::renderer_RenderBackstitches());
@@ -1622,10 +1632,10 @@ void MainWindow::setupActions()
 
 
     action = new KAction(this);
-    action->setText(i18n("Color Hilight"));
+    action->setText(i18n("Color Highlight"));
     action->setCheckable(true);
-    connect(action, SIGNAL(toggled(bool)), m_editor, SLOT(colorHilight(bool)));
-    actions->addAction("colorHilight", action);
+    connect(action, SIGNAL(toggled(bool)), m_editor, SLOT(colorHighlight(bool)));
+    actions->addAction("colorHighlight", action);
 
     action = new KAction(this);
     action->setText(i18n("Show Stitches"));
@@ -1746,8 +1756,8 @@ void MainWindow::setupDockWindows()
     dock = new QDockWidget(i18n("Imported Image"), this);
     dock->setObjectName("ImportedImage#");
     dock->setAllowedAreas(Qt::AllDockWidgetAreas);
-    m_imageLabel = new QLabel(this);
-    m_imageLabel->setScaledContents(true);
+    m_imageLabel = new ScaledPixmapLabel(this);
+    m_imageLabel->setScaledContents(false);
     dock->setWidget(m_imageLabel);
     addDockWidget(Qt::LeftDockWidgetArea, dock);
     actionCollection()->addAction("showImportedDockWidget", dock->toggleViewAction());
